@@ -6,7 +6,7 @@ from python_search.entry_runner import EntryRunner
 from python_search.environment import is_mac
 from python_search.events.run_performed import RunPerformed
 from python_search.events.run_performed.client import LogRunPerformedClient
-from python_search.search_ui.fzf_terminal import FzfInTerminal
+from python_search.search_ui.fzf_kitty import FzfInKitty
 from python_search.search_ui.preview import Preview
 
 
@@ -16,8 +16,8 @@ class PythonSearchCli:
 
     Try to avoid adding direct commands, prefer instead to add objects as parts of functions
     """
-    # all commands that are not self-explanatory should not be part of the main api, thus are marked as private.
 
+    # all commands that are not self-explanatory should not be part of the main api, thus are marked as private.
 
     configuration: PythonSearchConfiguration
 
@@ -64,14 +64,14 @@ class PythonSearchCli:
         """
         Opens the Search UI. Main entrypoint of the application
         """
-        FzfInTerminal.build_search_ui(self.configuration).run()
-
+        FzfInKitty.build_search_ui(self.configuration).run()
 
     def edit_main(self):
         """Edit the main script"""
         from python_search.entry_capture.edit_content import EditKey
 
         return EditKey(self.configuration).edit_default()
+
     def register_new(self):
         """Starts the UI for collecting a new entry into pythonsearch"""
         from python_search.entry_capture.register_new import RegisterNew
@@ -113,6 +113,7 @@ class PythonSearchCli:
         from python_search.shortcut.generator import ShortcutGenerator
 
         return ShortcutGenerator(self.configuration)
+
     def _search_edit(self, key=None):
         from python_search.entry_capture.edit_content import EditKey
 
@@ -124,9 +125,9 @@ class PythonSearchCli:
         return result
 
     def _ranking(self):
-        from python_search.ranking.ranking import RankingGenerator
+        from python_search.search.search import Search
 
-        return RankingGenerator(self.configuration)
+        return Search(self.configuration)
 
     def _features(self):
         """Feature toggle system"""
@@ -166,6 +167,17 @@ class PythonSearchCli:
 
         return Report()
 
+    def _entry_type_classifier(self):
+
+        from python_search.entry_type.classifier_inference import \
+            ClassifierInferenceClient
+
+        class EntryTypeClassifierAPI:
+            def __init__(self):
+                self.inference_client = ClassifierInferenceClient
+
+        return EntryTypeClassifierAPI
+
 
 def _error_handler(e):
     import sys
